pub fn parse_module_token(text: &str, start: usize) -> Option<ModuleTokenSpan>Expand description
Parse a module token that starts at start in text.
A module token is one or more identifier segments separated by either
:: (canonical) or ' (legacy) separators.